Index: wp-includes/class-wp.php
===================================================================
--- wp-includes/class-wp.php	(revision 17643)
+++ wp-includes/class-wp.php	(working copy)
@@ -186,8 +186,8 @@
 			// Look for matches.
 			$request_match = $request;
 			foreach ( (array) $rewrite as $match => $query) {
-				// Don't try to match against AtomPub calls
-				if ( $req_uri == 'wp-app.php' )
+				// Don't try to match against AtomPub calls or empty requests
+				if ( $req_uri == 'wp-app.php' ) || empty( $req_uri ) )
 					break;
 
 				// If the requesting file is the anchor of the match, prepend it
